import json
import zlib

import requests
from rich.console import Console

SOURCE = 'https://nvd.nist.gov/feeds/json/cve/1.1/nvdcve-1.1-recent.json.gz'
console = Console()


def get_data() -> list:
    """
        Downloads data from the NVD.

        :return:
    """

    r = requests.get(SOURCE)

    if not r.ok:
        console.print(f'[red]http request failed[/]')
        return []

    data = zlib.decompress(r.content, zlib.MAX_WBITS | 32)
    data = json.loads(data)["CVE_Items"]
    return sorted(data, key=lambda x: (x["cve"]["CVE_data_meta"]["ID"]))


def print_cve(cve: dict) -> None:
    """
        Print CVE information.

        :param cve:
        :return:
    """

    print('')
    cve = cve['cve']

    cve_id = cve["CVE_data_meta"]["ID"]
    description = cve["description"]["description_data"][0]["value"]
    references = cve["references"]["reference_data"]
    console.print(f'------ {cve_id} ------')
    console.print(f'{description}')
    for reference in references:
        console.print(f'{reference["tags"]} | url: {reference["url"]}')


def main():
    """
        The default entrypoint for CVESTREAM

        :return:
    """

    data = get_data()
    console.print(f'found {len(data)} cve\'s')

    if len(data) <= 0:
        return

    for cve in data:
        print_cve(cve)


if __name__ == '__main__':
    main()



import os

from setuptools import setup

version = "1.0.0"

# here - where we are.
here = os.path.abspath(os.path.dirname(__file__))

# read the package requirements for install_requires
with open(os.path.join(here, 'requirements.txt'), 'r') as f:
    requirements = f.readlines()

# setup!
setup(
    name='cvestream',

    author='Leon Jacobs',
    author_email='leonja511@gmail.com',

    description='a small utility to dump NVD information',
    license='GPL v3',
    packages=['cvestream'],
    install_requires=requirements,
    python_requires='>=3.5',

    url='https://github.com/leonjza/cvestream',
    download_url='https://github.com/leonjza/cvestream/archive/' + version + '.tar.gz',

    keywords=['docker', 'tool', 'pentest', 'framework'],
    version=version,

    classifiers=[
        'Operating System :: OS Independent',
        'Natural Language :: English',
        'Programming Language :: Python :: 3 :: Only',
    ],
    entry_points={
        'console_scripts': [
            'cvestream = cvestream.main:main',
        ],
    },
)
